==> honey-toolkit-1.0.27.tgz: package/fn/component.js <==
const path = require('path');
const fs = require('fs');
const transform = require('../util/transform');
const ncp = require('ncp').ncp;
const config = require('../config');

const Page = function(){

};

Page.createComponent = (name)=>{
  let nameU ,nameC ,nameD ,name_ ;
  if(name.indexOf("-") !== -1){
    nameD = name;
    name_ = transform(nameD ,"dash" ,"lodash");
    nameC = transform(nameD ,"dash" ,"camel");
    nameU = transform(nameD ,"dash" ,"upper");
  }else if(name.indexOf("_") !== -1){
    name_ = name;
    nameD = transform(name_ ,"lodash" ,"dash");
    nameC = transform(name_ ,"lodash" ,"camel");
    nameU = transform(name_ ,"lodash" ,"upper");
  }else if(/^[A-Z]/.test(name)){
    nameU = name;
    nameD = transform(nameU ,"upper" ,"dash");
    nameC = transform(nameU ,"upper" ,"camel");
    name_ = transform(nameU ,"upper" ,"lodash");
  }else {
    nameC = name;
    nameD = transform(nameC ,"camel" ,"dash");
    nameU = transform(nameC ,"camel" ,"upper");
    name_ = transform(nameC ,"camel" ,"lodash");
  }

  ncp(path.resolve(config.componentPath === '../templates/_SampleComponent' ? __dirname : '', config.componentPath),
      path.resolve('./src/components/' + nameU),
      {
        /*transform: function (read, write){
          console.log('read:',read);
        }*/
      },
      function(err){
        if (err) {
          return console.error(err);
        } else {
          change();
        }
      }
  );

  function change(){
    function reName(path, ele){
      var toEle = ele.replace(/sampleComponent/g,nameC).replace(/SampleComponent/g,nameU);
      if(toEle !== ele){
        fs.renameSync(path+"/"+ele, path+"/"+toEle);
      }
      return toEle;
    }
    function readDirSync(path){
      var pa = fs.readdirSync(path);
      pa.forEach(function(ele,index){
        ele = reName(path, ele);
        var info = fs.statSync(path+"/"+ele)
        if(info.isDirectory()){
          readDirSync(path+"/"+ele);
        }else{
          var text = fs.readFileSync(`${path}/${ele}` ,'utf-8')
          .replace(/sampleComponent/g, nameC)
          .replace(/SampleComponent/g, nameU);
          fs.writeFileSync(`${path}/${ele}`, text, { encoding:'utf-8', flag:'w' });
        }
      })
    }
    readDirSync(path.resolve('./src/components/' + nameU));
  }

  console.log('done');
  return {nameU, nameC, nameD, name_};
}
module.exports = Page;

==> honey-toolkit-1.0.32.tgz: package/fn/component.js <==
const path = require('path');
const fs = require('fs');
const transform = require('../util/transform');
const ncp = require('ncp').ncp;
const config = require('../config');

const Page = function(){

};

Page.createComponent = (name)=>{
  let nameU ,nameC ,nameD ,name_ ;
  if(name.indexOf("-") !== -1){
    nameD = name;
    name_ = transform(nameD ,"dash" ,"lodash");
    nameC = transform(nameD ,"dash" ,"camel");
    nameU = transform(nameD ,"dash" ,"upper");
  }else if(name.indexOf("_") !== -1){
    name_ = name;
    nameD = transform(name_ ,"lodash" ,"dash");
    nameC = transform(name_ ,"lodash" ,"camel");
    nameU = transform(name_ ,"lodash" ,"upper");
  }else if(/^[A-Z]/.test(name)){
    nameU = name;
    nameD = transform(nameU ,"upper" ,"dash");
    nameC = transform(nameU ,"upper" ,"camel");
    name_ = transform(nameU ,"upper" ,"lodash");
  }else {
    nameC = name;
    nameD = transform(nameC ,"camel" ,"dash");
    nameU = transform(nameC ,"camel" ,"upper");
    name_ = transform(nameC ,"camel" ,"lodash");
  }

  ncp(path.resolve(config.componentPath),
      path.resolve('./src/components/' + nameU),
      {
        /*transform: function (read, write){
          console.log('read:',read);
        }*/
      },
      function(err){
        if (err) {
          return console.error(err);
        } else {
          change();
        }
      }
  );

  function change(){
    function reName(path, ele){
      var toEle = ele.replace(/sampleComponent/g,nameC).replace(/SampleComponent/g,nameU);
      if(toEle !== ele){
        fs.renameSync(path+"/"+ele, path+"/"+toEle);
      }
      return toEle;
    }
    function readDirSync(path){
      var pa = fs.readdirSync(path);
      pa.forEach(function(ele,index){
        ele = reName(path, ele);
        var info = fs.statSync(path+"/"+ele)
        if(info.isDirectory()){
          readDirSync(path+"/"+ele);
        }else{
          var text = fs.readFileSync(`${path}/${ele}` ,'utf-8')
          .replace(/sampleComponent/g, nameC)
          .replace(/SampleComponent/g, nameU);
          fs.writeFileSync(`${path}/${ele}`, text, { encoding:'utf-8', flag:'w' });
        }
      })
    }
    readDirSync(path.resolve('./src/components/' + nameU));
  }

  console.log('done');
  return {nameU, nameC, nameD, name_};
}
module.exports = Page;
